pub struct BatchGetItemInput {
pub request_items: HashMap<String, KeysAndAttributes>,
pub return_consumed_capacity: Option<ReturnConsumedCapacity>,
}Expand description
Input for the BatchGetItem operation.
Fields
request_items: HashMap<String, KeysAndAttributes>A map of one or more table names to the corresponding keys and projection expressions to retrieve.
return_consumed_capacity: Option<ReturnConsumedCapacity>Determines the level of detail about provisioned throughput consumption.