pub struct GetItemInput {
pub table_name: String,
pub key: HashMap<String, AttributeValue>,
pub consistent_read: Option<bool>,
pub projection_expression: Option<String>,
pub expression_attribute_names: HashMap<String, String>,
pub return_consumed_capacity: Option<ReturnConsumedCapacity>,
pub attributes_to_get: Option<Vec<String>>,
}Expand description
Input for the GetItem operation.
Fields
table_name: StringThe name of the table containing the item.
key: HashMap<String, AttributeValue>A map of attribute names to AttributeValue objects representing the
primary key of the item to retrieve.
consistent_read: Option<bool>If true, a strongly consistent read is used; otherwise, an eventually
consistent read is used.
projection_expression: Option<String>A string that identifies the attributes to retrieve from the table.
expression_attribute_names: HashMap<String, String>Substitution tokens for attribute names in an expression.
return_consumed_capacity: Option<ReturnConsumedCapacity>Determines the level of detail about provisioned throughput consumption.
attributes_to_get: Option<Vec<String>>Legacy: attribute names to retrieve (use projection_expression instead).