pub struct ListTablesInput {
pub exclusive_start_table_name: Option<String>,
pub limit: Option<i32>,
}Expand description
Input for the ListTables operation.
Fields
exclusive_start_table_name: Option<String>The name of the table that starts the list. Use the value returned in
LastEvaluatedTableName from a previous request to continue pagination.
limit: Option<i32>The maximum number of table names to return (1–100).