pub struct QueryInput {Show 17 fields
pub table_name: String,
pub index_name: Option<String>,
pub key_condition_expression: Option<String>,
pub filter_expression: Option<String>,
pub projection_expression: Option<String>,
pub expression_attribute_names: HashMap<String, String>,
pub expression_attribute_values: HashMap<String, AttributeValue>,
pub scan_index_forward: Option<bool>,
pub limit: Option<i32>,
pub exclusive_start_key: HashMap<String, AttributeValue>,
pub select: Option<Select>,
pub consistent_read: Option<bool>,
pub return_consumed_capacity: Option<ReturnConsumedCapacity>,
pub key_conditions: HashMap<String, Condition>,
pub query_filter: HashMap<String, Condition>,
pub attributes_to_get: Option<Vec<String>>,
pub conditional_operator: Option<ConditionalOperator>,
}Expand description
Input for the Query operation.
Fields
table_name: StringThe name of the table to query.
index_name: Option<String>The name of a secondary index to query.
key_condition_expression: Option<String>The condition that specifies the key values for items to be retrieved.
filter_expression: Option<String>A string that contains conditions for filtering the query results.
projection_expression: Option<String>A string that identifies the attributes to retrieve from the table.
expression_attribute_names: HashMap<String, String>Substitution tokens for attribute names in an expression.
expression_attribute_values: HashMap<String, AttributeValue>Substitution tokens for attribute values in an expression.
scan_index_forward: Option<bool>Specifies the order of index traversal. true (default) for ascending,
false for descending.
limit: Option<i32>The maximum number of items to evaluate (not necessarily the number of matching items).
exclusive_start_key: HashMap<String, AttributeValue>The primary key of the first item that this operation will evaluate. Used for pagination.
select: Option<Select>The attributes to be returned in the result.
consistent_read: Option<bool>If true, a strongly consistent read is used.
return_consumed_capacity: Option<ReturnConsumedCapacity>Determines the level of detail about provisioned throughput consumption.
key_conditions: HashMap<String, Condition>Legacy: key conditions (use key_condition_expression instead).
query_filter: HashMap<String, Condition>Legacy: query filter (use filter_expression instead).
attributes_to_get: Option<Vec<String>>Legacy: attribute names to retrieve (use projection_expression instead).
conditional_operator: Option<ConditionalOperator>Legacy: logical operator for combining multiple query filter conditions.