ScanInput

Struct ScanInput 

pub struct ScanInput {
Show 16 fields pub table_name: String, pub index_name: Option<String>, pub filter_expression: Option<String>, pub projection_expression: Option<String>, pub expression_attribute_names: HashMap<String, String>, pub expression_attribute_values: HashMap<String, AttributeValue>, pub limit: Option<i32>, pub exclusive_start_key: HashMap<String, AttributeValue>, pub segment: Option<i32>, pub total_segments: Option<i32>, pub select: Option<Select>, pub consistent_read: Option<bool>, pub return_consumed_capacity: Option<ReturnConsumedCapacity>, pub scan_filter: HashMap<String, Condition>, pub attributes_to_get: Option<Vec<String>>, pub conditional_operator: Option<ConditionalOperator>,
}
Input for the Scan operation.

Fields

table_name: String

The name of the table to scan.

index_name: Option<String>

The name of a secondary index to scan.

filter_expression: Option<String>

A string that contains conditions for filtering the scan results.

projection_expression: Option<String>

A string that identifies the attributes to retrieve from the table.

expression_attribute_names: HashMap<String, String>

Substitution tokens for attribute names in an expression.

expression_attribute_values: HashMap<String, AttributeValue>

Substitution tokens for attribute values in an expression.

limit: Option<i32>

The maximum number of items to evaluate.

exclusive_start_key: HashMap<String, AttributeValue>

The primary key of the first item that this operation will evaluate. Used for pagination.

segment: Option<i32>

For a parallel Scan request, identifies an individual segment to be scanned by an application worker.

total_segments: Option<i32>

For a parallel Scan request, the total number of segments into which the table is divided.

select: Option<Select>

The attributes to be returned in the result.

consistent_read: Option<bool>

If true, a strongly consistent read is used.

return_consumed_capacity: Option<ReturnConsumedCapacity>

Determines the level of detail about provisioned throughput consumption.

scan_filter: HashMap<String, Condition>

Legacy: scan filter (use filter_expression instead).

attributes_to_get: Option<Vec<String>>

Legacy: attribute names to retrieve (use projection_expression instead).

conditional_operator: Option<ConditionalOperator>

Legacy: logical operator for combining multiple scan filter conditions.