pub struct BatchGetItemOutput {
pub responses: HashMap<String, Vec<HashMap<String, AttributeValue>>>,
pub unprocessed_keys: HashMap<String, KeysAndAttributes>,
pub consumed_capacity: Vec<ConsumedCapacity>,
}Expand description
Output for the BatchGetItem operation.
Fields
responses: HashMap<String, Vec<HashMap<String, AttributeValue>>>A map of table names to the items retrieved from each table.
unprocessed_keys: HashMap<String, KeysAndAttributes>A map of tables and their respective keys that were not processed. Use
these values as RequestItems in a subsequent BatchGetItem call.
consumed_capacity: Vec<ConsumedCapacity>The capacity units consumed by the operation for each table.