pub struct BatchWriteItemOutput {
pub unprocessed_items: HashMap<String, Vec<WriteRequest>>,
pub item_collection_metrics: HashMap<String, Vec<ItemCollectionMetrics>>,
pub consumed_capacity: Vec<ConsumedCapacity>,
}Expand description
Output for the BatchWriteItem operation.
Fields
unprocessed_items: HashMap<String, Vec<WriteRequest>>A map of tables and their respective WriteRequest objects that were
not processed. Use these values as RequestItems in a subsequent
BatchWriteItem call.
item_collection_metrics: HashMap<String, Vec<ItemCollectionMetrics>>A map of tables to item collection metrics for the tables that were affected by the operation.
consumed_capacity: Vec<ConsumedCapacity>The capacity units consumed by the operation for each table.