pub struct ListTablesOutput {
pub table_names: Vec<String>,
pub last_evaluated_table_name: Option<String>,
}Expand description
Output for the ListTables operation.
Fields
table_names: Vec<String>The names of the tables associated with the current account and region.
last_evaluated_table_name: Option<String>The name of the last table in the current page of results. Use this
value as ExclusiveStartTableName in a subsequent request to continue.