pub struct QueryOutput {
pub items: Option<Vec<HashMap<String, AttributeValue>>>,
pub count: i32,
pub scanned_count: i32,
pub last_evaluated_key: HashMap<String, AttributeValue>,
pub consumed_capacity: Option<ConsumedCapacity>,
}Expand description
Output for the Query operation.
Fields
items: Option<Vec<HashMap<String, AttributeValue>>>An array of item attributes that match the query conditions.
None when Select=COUNT (omitted from JSON), Some(vec) otherwise
(always serialized, even when empty).
count: i32The number of items in the response.
scanned_count: i32The number of items evaluated before the filter expression was applied.
last_evaluated_key: HashMap<String, AttributeValue>The primary key of the item where the query operation stopped. Use this
value as ExclusiveStartKey in a subsequent query to continue.
consumed_capacity: Option<ConsumedCapacity>The capacity units consumed by the operation.