pub struct TransactGetItemsOutput {
pub consumed_capacity: Vec<ConsumedCapacity>,
pub responses: Option<Vec<ItemResponse>>,
}Expand description
Output for the TransactGetItems operation.
Fields
consumed_capacity: Vec<ConsumedCapacity>The capacity units consumed by the operation for each table.
responses: Option<Vec<ItemResponse>>The items retrieved, in the same order as the input.