pub struct KeysAndAttributes {
pub keys: Vec<HashMap<String, AttributeValue>>,
pub projection_expression: Option<String>,
pub expression_attribute_names: Option<HashMap<String, String>>,
pub consistent_read: Option<bool>,
pub attributes_to_get: Vec<String>,
}Expand description
A set of keys and optional projection for BatchGetItem.
Describes the items to retrieve from a single table.
Fields
keys: Vec<HashMap<String, AttributeValue>>The primary keys of the items to retrieve.
projection_expression: Option<String>The attributes to retrieve. If not specified, all attributes are returned.
expression_attribute_names: Option<HashMap<String, String>>Expression attribute names for substitution in projection_expression.
consistent_read: Option<bool>Whether to use a consistent read.
attributes_to_get: Vec<String>Legacy: attribute names to retrieve (use projection_expression instead).