pub struct ProvisionedThroughput {
pub read_capacity_units: i64,
pub write_capacity_units: i64,
}Expand description
Provisioned throughput settings for a table or GSI (input).
Specifies the read and write capacity units to provision. For on-demand tables this is accepted but not enforced.
Fields
read_capacity_units: i64The maximum number of strongly consistent reads per second.
write_capacity_units: i64The maximum number of writes per second.