pub type Item = HashMap<String, AttributeValue>;Expand description
A DynamoDB item represented as a map of attribute names to values.
Aliased Type
pub struct Item { /* private fields */ }pub type Item = HashMap<String, AttributeValue>;A DynamoDB item represented as a map of attribute names to values.
pub struct Item { /* private fields */ }