pub type Key = HashMap<String, AttributeValue>;Expand description
A DynamoDB key represented as a map of key attribute names to values.
Aliased Type
pub struct Key { /* private fields */ }pub type Key = HashMap<String, AttributeValue>;A DynamoDB key represented as a map of key attribute names to values.
pub struct Key { /* private fields */ }